@@ -28,7 +28,7 @@ import uuid
 import warnings
 from copy import deepcopy
 from tempfile import TemporaryDirectory
-from typing import Any, Callable, List, Optional, Sequence, TypeVar, Union, cast
+from typing import Any, Callable, Dict, List, Optional, Sequence, Set, TypeVar, Union, cast
 
 from googleapiclient.discovery import build
 
@@ -36,14 +36,15 @@ from airflow.exceptions import AirflowException
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 from airflow.utils.log.logging_mixin import LoggingMixin
 from airflow.providers.google.common.utils.python_virtualenv import prepare_virtualenv
+from airflow.utils.timeout import timeout
 
 # This is the default location
 # https://cloud.google.com/dataflow/pipelines/specifying-exec-params
-DEFAULT_DATAFLOW_LOCATION = 'us-central1'
+DEFAULT_DATAFLOW_LOCATION = "us-central1"
 
 
 JOB_ID_PATTERN = re.compile(
-    r'Submitted job: (?P<job_id_java>.*)|Created job with id: \[(?P<job_id_python>.*)\]'
+    r"Submitted job: (?P<job_id_java>.*)|Created job with id: \[(?P<job_id_python>.*)\]"
 )
 
 T = TypeVar("T", bound=Callable)  # pylint: disable=invalid-name
@@ -66,7 +67,7 @@ def _fallback_variable_parameter(parameter_name: str, variable_key_name: str) ->
                 )
 
             parameter_location = kwargs.get(parameter_name)
-            variables_location = kwargs.get('variables', {}).get(variable_key_name)
+            variables_location = kwargs.get("variables", {}).get(variable_key_name)
 
             if parameter_location and variables_location:
                 raise AirflowException(
@@ -76,9 +77,9 @@ def _fallback_variable_parameter(parameter_name: str, variable_key_name: str) ->
             if parameter_location or variables_location:
                 kwargs[parameter_name] = parameter_location or variables_location
             if variables_location:
-                copy_variables = deepcopy(kwargs['variables'])
+                copy_variables = deepcopy(kwargs["variables"])
                 del copy_variables[variable_key_name]
-                kwargs['variables'] = copy_variables
+                kwargs["variables"] = copy_variables
 
             return func(self, *args, **kwargs)
 
@@ -87,8 +88,8 @@ def _fallback_variable_parameter(parameter_name: str, variable_key_name: str) ->
     return _wrapper
 
 
-_fallback_to_location_from_variables = _fallback_variable_parameter('location', 'region')
-_fallback_to_project_id_from_variables = _fallback_variable_parameter('project_id', 'project')
+_fallback_to_location_from_variables = _fallback_variable_parameter("location", "region")
+_fallback_to_project_id_from_variables = _fallback_variable_parameter("project_id", "project")
 
 
 class DataflowJobStatus:
@@ -145,9 +146,19 @@ class _DataflowJobsController(LoggingMixin):
     :param num_retries: Maximum number of retries in case of connection problems.
     :param multiple_jobs: If set to true this task will be searched by name prefix (``name`` parameter),
         not by specific job ID, then actions will be performed on all matching jobs.
+    :param drain_pipeline: Optional, set to True if want to stop streaming job by draining it
+        instead of canceling.
+    :param cancel_timeout: wait time in seconds for successful job canceling
+    :param wait_until_finished: If True, wait for the end of pipeline execution before exiting. If False,
+        it only submits job and check once is job not in terminal state.
+
+        The default behavior depends on the type of pipeline:
+
+        * for the streaming pipeline, wait for jobs to start,
+        * for the batch pipeline, wait for the jobs to complete.
     """
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments
         self,
         dataflow: Any,
         project_number: str,
@@ -157,6 +168,9 @@ class _DataflowJobsController(LoggingMixin):
         job_id: Optional[str] = None,
         num_retries: int = 0,
         multiple_jobs: bool = False,
+        drain_pipeline: bool = False,
+        cancel_timeout: Optional[int] = 5 * 60,
+        wait_until_finished: Optional[bool] = None,
     ) -> None:
 
         super().__init__()
@@ -168,6 +182,10 @@ class _DataflowJobsController(LoggingMixin):
         self._job_id = job_id
         self._num_retries = num_retries
         self._poll_sleep = poll_sleep
+        self._cancel_timeout = cancel_timeout
+        self._jobs: Optional[List[dict]] = None
+        self.drain_pipeline = drain_pipeline
+        self._wait_until_finished = wait_until_finished
         self._jobs: Optional[List[dict]] = None
 
     def is_job_running(self) -> bool:
@@ -182,7 +200,7 @@ class _DataflowJobsController(LoggingMixin):
             return False
 
         for job in self._jobs:
-            if job['currentState'] not in DataflowJobStatus.TERMINAL_STATES:
+            if job["currentState"] not in DataflowJobStatus.TERMINAL_STATES:
                 return True
         return False
 
@@ -195,24 +213,57 @@ class _DataflowJobsController(LoggingMixin):
         :rtype: list
         """
         if not self._multiple_jobs and self._job_id:
-            return [self._fetch_job_by_id(self._job_id)]
+            return [self.fetch_job_by_id(self._job_id)]
         elif self._job_name:
             jobs = self._fetch_jobs_by_prefix_name(self._job_name.lower())
             if len(jobs) == 1:
-                self._job_id = jobs[0]['id']
+                self._job_id = jobs[0]["id"]
             return jobs
         else:
-            raise Exception('Missing both dataflow job ID and name.')
+            raise Exception("Missing both dataflow job ID and name.")
 
-    def _fetch_job_by_id(self, job_id: str) -> dict:
+    def fetch_job_by_id(self, job_id: str) -> dict:
+        """
+        Helper method to fetch the job with the specified Job ID.
+
+        :param job_id: Job ID to get.
+        :type job_id: str
+        :return: the Job
+        :rtype: dict
+        """
         return (
             self._dataflow.projects()
             .locations()
             .jobs()
-            .get(projectId=self._project_number, location=self._job_location, jobId=job_id)
+            .get(
+                projectId=self._project_number,
+                location=self._job_location,
+                jobId=job_id,
+            )
             .execute(num_retries=self._num_retries)
         )
 
+    def fetch_job_metrics_by_id(self, job_id: str) -> dict:
+        """
+        Helper method to fetch the job metrics with the specified Job ID.
+
+        :param job_id: Job ID to get.
+        :type job_id: str
+        :return: the JobMetrics. See:
+            https://cloud.google.com/dataflow/docs/reference/rest/v1b3/JobMetrics
+        :rtype: dict
+        """
+        result = (
+            self._dataflow.projects()
+            .locations()
+            .jobs()
+            .getMetrics(projectId=self._project_number, location=self._job_location, jobId=job_id)
+            .execute(num_retries=self._num_retries)
+        )
+
+        self.log.debug("fetch_job_metrics_by_id %s:\n%s", job_id, result)
+        return result
+
     def _fetch_all_jobs(self) -> List[dict]:
         request = (
             self._dataflow.projects()
@@ -235,7 +286,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def _fetch_jobs_by_prefix_name(self, prefix_name: str) -> List[dict]:
         jobs = self._fetch_all_jobs()
-        jobs = [job for job in jobs if job['name'].startswith(prefix_name)]
+        jobs = [job for job in jobs if job["name"].startswith(prefix_name)]
         return jobs
 
     def _refresh_jobs(self) -> None:
@@ -249,9 +300,13 @@ class _DataflowJobsController(LoggingMixin):
 
         if self._jobs:
             for job in self._jobs:
-                self.log.info('Google Cloud DataFlow job %s is state: %s', job['name'], job['currentState'])
+                self.log.info(
+                    "Google Cloud DataFlow job %s is state: %s",
+                    job["name"],
+                    job["currentState"],
+                )
         else:
-            self.log.info('Google Cloud DataFlow job not available yet..')
+            self.log.info("Google Cloud DataFlow job not available yet..")
 
     def _check_dataflow_job_state(self, job) -> bool:
         """
@@ -262,22 +317,28 @@ class _DataflowJobsController(LoggingMixin):
         :rtype: bool
         :raise: Exception
         """
-        if DataflowJobStatus.JOB_STATE_DONE == job['currentState']:
+        if self._wait_until_finished is None:
+            wait_for_running = job['type'] == DataflowJobType.JOB_TYPE_STREAMING
+        else:
+            wait_for_running = not self._wait_until_finished
+
+        if job['currentState'] == DataflowJobStatus.JOB_STATE_DONE:
             return True
-        elif DataflowJobStatus.JOB_STATE_FAILED == job['currentState']:
+        elif job['currentState'] == DataflowJobStatus.JOB_STATE_FAILED:
             raise Exception("Google Cloud Dataflow job {} has failed.".format(job['name']))
-        elif DataflowJobStatus.JOB_STATE_CANCELLED == job['currentState']:
+        elif job['currentState'] == DataflowJobStatus.JOB_STATE_CANCELLED:
             raise Exception("Google Cloud Dataflow job {} was cancelled.".format(job['name']))
-        elif (
-            DataflowJobStatus.JOB_STATE_RUNNING == job['currentState']
-            and DataflowJobType.JOB_TYPE_STREAMING == job['type']
-        ):
+        elif job['currentState'] == DataflowJobStatus.JOB_STATE_DRAINED:
+            raise Exception("Google Cloud Dataflow job {} was drained.".format(job['name']))
+        elif job['currentState'] == DataflowJobStatus.JOB_STATE_UPDATED:
+            raise Exception("Google Cloud Dataflow job {} was updated.".format(job['name']))
+        elif job['currentState'] == DataflowJobStatus.JOB_STATE_RUNNING and wait_for_running:
             return True
         elif job['currentState'] in DataflowJobStatus.AWAITING_STATES:
-            return False
+            return self._wait_until_finished is False
         self.log.debug("Current job: %s", str(job))
         raise Exception(
-            "Google Cloud Dataflow job {} was unknown state: {}".format(job['name'], job['currentState'])
+            "Google Cloud Dataflow job {} was unknown state: {}".format(job["name"], job["currentState"])
         )
 
     def wait_for_done(self) -> None:
@@ -289,10 +350,12 @@ class _DataflowJobsController(LoggingMixin):
             time.sleep(self._poll_sleep)
             self._refresh_jobs()
 
-    def get_jobs(self, refresh=False) -> List[dict]:
+    def get_jobs(self, refresh: bool = False) -> List[dict]:
         """
         Returns Dataflow jobs.
 
+        :param refresh: Forces the latest data to be fetched.
+        :type refresh: bool
         :return: list of jobs
         :rtype: list
         """
@@ -303,14 +366,42 @@ class _DataflowJobsController(LoggingMixin):
 
         return self._jobs
 
+    def _wait_for_states(self, expected_states: Set[str]):
+        """Waiting for the jobs to reach a certain state."""
+        if not self._jobs:
+            raise ValueError("The _jobs should be set")
+        while True:
+            self._refresh_jobs()
+            job_states = {job['currentState'] for job in self._jobs}
+            if not job_states.difference(expected_states):
+                return
+            unexpected_failed_end_states = expected_states - DataflowJobStatus.FAILED_END_STATES
+            if unexpected_failed_end_states.intersection(job_states):
+                unexpected_failed_jobs = {
+                    job for job in self._jobs if job['currentState'] in unexpected_failed_end_states
+                }
+                raise AirflowException(
+                    "Jobs failed: "
+                    + ", ".join(
+                        f"ID: {job['id']} name: {job['name']} state: {job['currentState']}"
+                        for job in unexpected_failed_jobs
+                    )
+                )
+            time.sleep(self._poll_sleep)
+
     def cancel(self) -> None:
-        """Cancels current job"""
+        """Cancels or drains current job"""
         jobs = self.get_jobs()
-        job_ids = [job['id'] for job in jobs if job['currentState'] not in DataflowJobStatus.TERMINAL_STATES]
+        job_ids = [job["id"] for job in jobs if job["currentState"] not in DataflowJobStatus.TERMINAL_STATES]
         if job_ids:
             batch = self._dataflow.new_batch_http_request()
             self.log.info("Canceling jobs: %s", ", ".join(job_ids))
-            for job_id in job_ids:
+            for job in jobs:
+                requested_state = (
+                    DataflowJobStatus.JOB_STATE_DRAINED
+                    if self.drain_pipeline and job["type"] == DataflowJobType.JOB_TYPE_STREAMING
+                    else DataflowJobStatus.JOB_STATE_CANCELLED
+                )
                 batch.add(
                     self._dataflow.projects()
                     .locations()
@@ -318,25 +409,37 @@ class _DataflowJobsController(LoggingMixin):
                     .update(
                         projectId=self._project_number,
                         location=self._job_location,
-                        jobId=job_id,
-                        body={"requestedState": DataflowJobStatus.JOB_STATE_CANCELLED},
+                        jobId=job["id"],
+                        body={"requestedState": requested_state},
                     )
                 )
             batch.execute()
+            if self._cancel_timeout and isinstance(self._cancel_timeout, int):
+                timeout_error_message = "Canceling jobs failed due to timeout ({}s): {}".format(
+                    self._cancel_timeout, ", ".join(job_ids)
+                )
+                with timeout(seconds=self._cancel_timeout, error_message=timeout_error_message):
+                    self._wait_for_states({DataflowJobStatus.JOB_STATE_CANCELLED})
         else:
             self.log.info("No jobs to cancel")
 
 
 class _DataflowRunner(LoggingMixin):
     def __init__(
-        self, cmd: List[str], on_new_job_id_callback: Optional[Callable[[str], None]] = None
+        self,
+        cmd: List[str],
+        on_new_job_id_callback: Optional[Callable[[str], None]] = None,
     ) -> None:
         super().__init__()
-        self.log.info("Running command: %s", ' '.join(shlex.quote(c) for c in cmd))
+        self.log.info("Running command: %s", " ".join(shlex.quote(c) for c in cmd))
         self.on_new_job_id_callback = on_new_job_id_callback
         self.job_id: Optional[str] = None
         self._proc = subprocess.Popen(
-            cmd, shell=False, stdout=subprocess.PIPE, stderr=subprocess.PIPE, close_fds=True
+            cmd,
+            shell=False,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            close_fds=True,
         )
 
     def _process_fd(self, fd):
@@ -373,7 +476,7 @@ class _DataflowRunner(LoggingMixin):
         # Job id info: https://goo.gl/SE29y9.
         matched_job = JOB_ID_PATTERN.search(line)
         if matched_job:
-            job_id = matched_job.group('job_id_java') or matched_job.group('job_id_python')
+            job_id = matched_job.group("job_id_java") or matched_job.group("job_id_python")
             self.log.info("Found Job ID: %s", job_id)
             self.job_id = job_id
             if self.on_new_job_id_callback:
@@ -409,7 +512,7 @@ class _DataflowRunner(LoggingMixin):
         self.log.info("Process exited with return code: %s", self._proc.returncode)
 
         if self._proc.returncode != 0:
-            raise Exception("DataFlow failed with return code {}".format(self._proc.returncode))
+            raise Exception(f"DataFlow failed with return code {self._proc.returncode}")
         return self.job_id
 
 
@@ -427,8 +530,14 @@ class DataflowHook(GoogleBaseHook):
         delegate_to: Optional[str] = None,
         poll_sleep: int = 10,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        drain_pipeline: bool = False,
+        cancel_timeout: Optional[int] = 5 * 60,
+        wait_until_finished: Optional[bool] = None,
     ) -> None:
         self.poll_sleep = poll_sleep
+        self.drain_pipeline = drain_pipeline
+        self.cancel_timeout = cancel_timeout
+        self.wait_until_finished = wait_until_finished
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
@@ -438,7 +547,7 @@ class DataflowHook(GoogleBaseHook):
     def get_conn(self) -> build:
         """Returns a Google Cloud Dataflow service object."""
         http_authorized = self._authorize()
-        return build('dataflow', 'v1b3', http=http_authorized, cache_discovery=False)
+        return build("dataflow", "v1b3", http=http_authorized, cache_discovery=False)
 
     @GoogleBaseHook.provide_gcp_credential_file
     def _start_dataflow(
@@ -446,13 +555,17 @@ class DataflowHook(GoogleBaseHook):
         variables: dict,
         name: str,
         command_prefix: List[str],
-        label_formatter: Callable[[dict], List[str]],
         project_id: str,
         multiple_jobs: bool = False,
         on_new_job_id_callback: Optional[Callable[[str], None]] = None,
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ) -> None:
-        cmd = command_prefix + self._build_cmd(variables, label_formatter, project_id)
+        cmd = command_prefix + [
+            "--runner=DataflowRunner",
+            f"--project={project_id}",
+        ]
+        if variables:
+            cmd.extend(self._options_to_args(variables))
         runner = _DataflowRunner(cmd=cmd, on_new_job_id_callback=on_new_job_id_callback)
         job_id = runner.wait_for_done()
         job_controller = _DataflowJobsController(
@@ -464,6 +577,9 @@ class DataflowHook(GoogleBaseHook):
             job_id=job_id,
             num_retries=self.num_retries,
             multiple_jobs=multiple_jobs,
+            drain_pipeline=self.drain_pipeline,
+            cancel_timeout=self.cancel_timeout,
+            wait_until_finished=self.wait_until_finished,
         )
         job_controller.wait_for_done()
 
@@ -505,18 +621,17 @@ class DataflowHook(GoogleBaseHook):
         :type location: str
         """
         name = self._build_dataflow_job_name(job_name, append_job_name)
-        variables['jobName'] = name
-        variables['region'] = location
+        variables["jobName"] = name
+        variables["region"] = location
 
-        def label_formatter(labels_dict):
-            return ['--labels={}'.format(json.dumps(labels_dict).replace(' ', ''))]
+        if "labels" in variables:
+            variables["labels"] = json.dumps(variables["labels"], separators=(",", ":"))
 
         command_prefix = ["java", "-cp", jar, job_class] if job_class else ["java", "-jar", jar]
         self._start_dataflow(
             variables=variables,
             name=name,
             command_prefix=command_prefix,
-            label_formatter=label_formatter,
             project_id=project_id,
             multiple_jobs=multiple_jobs,
             on_new_job_id_callback=on_new_job_id_callback,
@@ -579,21 +694,21 @@ class DataflowHook(GoogleBaseHook):
         # available keys for runtime environment are listed here:
         # https://cloud.google.com/dataflow/docs/reference/rest/v1b3/RuntimeEnvironment
         environment_keys = [
-            'numWorkers',
-            'maxWorkers',
-            'zone',
-            'serviceAccountEmail',
-            'tempLocation',
-            'bypassTempDirValidation',
-            'machineType',
-            'additionalExperiments',
-            'network',
-            'subnetwork',
-            'additionalUserLabels',
-            'kmsKeyName',
-            'ipConfiguration',
-            'workerRegion',
-            'workerZone',
+            "numWorkers",
+            "maxWorkers",
+            "zone",
+            "serviceAccountEmail",
+            "tempLocation",
+            "bypassTempDirValidation",
+            "machineType",
+            "additionalExperiments",
+            "network",
+            "subnetwork",
+            "additionalUserLabels",
+            "kmsKeyName",
+            "ipConfiguration",
+            "workerRegion",
+            "workerZone",
         ]
 
         for key in variables:
@@ -616,12 +731,16 @@ class DataflowHook(GoogleBaseHook):
                 projectId=project_id,
                 location=location,
                 gcsPath=dataflow_template,
-                body={"jobName": name, "parameters": parameters, "environment": environment},
+                body={
+                    "jobName": name,
+                    "parameters": parameters,
+                    "environment": environment,
+                },
             )
         )
         response = request.execute(num_retries=self.num_retries)
 
-        job_id = response['job']['id']
+        job_id = response["job"]["id"]
         if on_new_job_id_callback:
             on_new_job_id_callback(job_id)
 
@@ -633,6 +752,8 @@ class DataflowHook(GoogleBaseHook):
             location=location,
             poll_sleep=self.poll_sleep,
             num_retries=self.num_retries,
+            drain_pipeline=self.drain_pipeline,
+            cancel_timeout=self.cancel_timeout,
         )
         jobs_controller.wait_for_done()
         return response["job"]
@@ -666,7 +787,7 @@ class DataflowHook(GoogleBaseHook):
             .launch(projectId=project_id, body=body, location=location)
         )
         response = request.execute(num_retries=self.num_retries)
-        job_id = response['job']['id']
+        job_id = response["job"]["id"]
 
         if on_new_job_id_callback:
             on_new_job_id_callback(job_id)
@@ -678,6 +799,7 @@ class DataflowHook(GoogleBaseHook):
             location=location,
             poll_sleep=self.poll_sleep,
             num_retries=self.num_retries,
+            cancel_timeout=self.cancel_timeout,
         )
         jobs_controller.wait_for_done()
 
@@ -740,11 +862,11 @@ class DataflowHook(GoogleBaseHook):
         :type location: str
         """
         name = self._build_dataflow_job_name(job_name, append_job_name)
-        variables['job_name'] = name
-        variables['region'] = location
+        variables["job_name"] = name
+        variables["region"] = location
 
-        def label_formatter(labels_dict):
-            return ['--labels={}={}'.format(key, value) for key, value in labels_dict.items()]
+        if "labels" in variables:
+            variables["labels"] = [f"{key}={value}" for key, value in variables["labels"].items()]
 
         if py_requirements is not None:
             if not py_requirements and not py_system_site_packages:
@@ -760,7 +882,7 @@ class DataflowHook(GoogleBaseHook):
                 )
                 raise AirflowException(warning_invalid_environment)
 
-            with TemporaryDirectory(prefix='dataflow-venv') as tmp_dir:
+            with TemporaryDirectory(prefix="dataflow-venv") as tmp_dir:
                 py_interpreter = prepare_virtualenv(
                     venv_directory=tmp_dir,
                     python_bin=py_interpreter,
@@ -773,7 +895,6 @@ class DataflowHook(GoogleBaseHook):
                     variables=variables,
                     name=name,
                     command_prefix=command_prefix,
-                    label_formatter=label_formatter,
                     project_id=project_id,
                     on_new_job_id_callback=on_new_job_id_callback,
                     location=location,
@@ -785,7 +906,6 @@ class DataflowHook(GoogleBaseHook):
                 variables=variables,
                 name=name,
                 command_prefix=command_prefix,
-                label_formatter=label_formatter,
                 project_id=project_id,
                 on_new_job_id_callback=on_new_job_id_callback,
                 location=location,
@@ -793,13 +913,13 @@ class DataflowHook(GoogleBaseHook):
 
     @staticmethod
     def _build_dataflow_job_name(job_name: str, append_job_name: bool = True) -> str:
-        base_job_name = str(job_name).replace('_', '-')
+        base_job_name = str(job_name).replace("_", "-")
 
         if not re.match(r"^[a-z]([-a-z0-9]*[a-z0-9])?$", base_job_name):
             raise ValueError(
-                'Invalid job_name ({}); the name must consist of'
-                'only the characters [-a-z0-9], starting with a '
-                'letter and ending with a letter or number '.format(base_job_name)
+                "Invalid job_name ({}); the name must consist of"
+                "only the characters [-a-z0-9], starting with a "
+                "letter and ending with a letter or number ".format(base_job_name)
             )
 
         if append_job_name:
@@ -810,29 +930,21 @@ class DataflowHook(GoogleBaseHook):
         return safe_job_name
 
     @staticmethod
-    def _build_cmd(variables: dict, label_formatter: Callable, project_id: str) -> List[str]:
-        command = [
-            "--runner=DataflowRunner",
-            "--project={}".format(project_id),
-        ]
-        if variables is None:
-            return command
-
+    def _options_to_args(variables: dict) -> List[str]:
+        if not variables:
+            return []
         # The logic of this method should be compatible with Apache Beam:
         # https://github.com/apache/beam/blob/b56740f0e8cd80c2873412847d0b336837429fb9/sdks/python/
         # apache_beam/options/pipeline_options.py#L230-L251
+        args: List[str] = []
         for attr, value in variables.items():
-            if attr == 'labels':
-                command += label_formatter(value)
-            elif value is None:
-                command.append(f"--{attr}")
-            elif isinstance(value, bool) and value:
-                command.append(f"--{attr}")
+            if value is None or (isinstance(value, bool) and value):
+                args.append(f"--{attr}")
             elif isinstance(value, list):
-                command.extend([f"--{attr}={v}" for v in value])
+                args.extend([f"--{attr}={v}" for v in value])
             else:
-                command.append(f"--{attr}={value}")
-        return command
+                args.append(f"--{attr}={value}")
+        return args
 
     @_fallback_to_location_from_variables
     @_fallback_to_project_id_from_variables
@@ -870,6 +982,9 @@ class DataflowHook(GoogleBaseHook):
             name=name,
             location=location,
             poll_sleep=self.poll_sleep,
+            drain_pipeline=self.drain_pipeline,
+            num_retries=self.num_retries,
+            cancel_timeout=self.cancel_timeout,
         )
         return jobs_controller.is_job_running()
 
@@ -903,5 +1018,135 @@ class DataflowHook(GoogleBaseHook):
             job_id=job_id,
             location=location,
             poll_sleep=self.poll_sleep,
+            drain_pipeline=self.drain_pipeline,
+            num_retries=self.num_retries,
+            cancel_timeout=self.cancel_timeout,
         )
         jobs_controller.cancel()
+
+    @GoogleBaseHook.fallback_to_default_project_id
+    def start_sql_job(
+        self,
+        job_name: str,
+        query: str,
+        options: Dict[str, Any],
+        project_id: str,
+        location: str = DEFAULT_DATAFLOW_LOCATION,
+        on_new_job_id_callback: Optional[Callable[[str], None]] = None,
+    ):
+        """
+        Starts Dataflow SQL query.
+
+        :param job_name: The unique name to assign to the Cloud Dataflow job.
+        :type job_name: str
+        :param query: The SQL query to execute.
+        :type query: str
+        :param options: Job parameters to be executed.
+            For more information, look at:
+            `https://cloud.google.com/sdk/gcloud/reference/beta/dataflow/sql/query
+            <gcloud beta dataflow sql query>`__
+            command reference
+        :param location: The location of the Dataflow job (for example europe-west1)
+        :type location: str
+        :param project_id: The ID of the GCP project that owns the job.
+            If set to ``None`` or missing, the default project_id from the GCP connection is used.
+        :type project_id: Optional[str]
+        :param on_new_job_id_callback: Callback called when the job ID is known.
+        :type on_new_job_id_callback: callable
+        :return: the new job object
+        """
+        cmd = [
+            "gcloud",
+            "dataflow",
+            "sql",
+            "query",
+            query,
+            f"--project={project_id}",
+            "--format=value(job.id)",
+            f"--job-name={job_name}",
+            f"--region={location}",
+            *(self._options_to_args(options)),
+        ]
+        self.log.info("Executing command: %s", " ".join([shlex.quote(c) for c in cmd]))
+        with self.provide_authorized_gcloud():
+            proc = subprocess.run(  # pylint: disable=subprocess-run-check
+                cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+            )
+        self.log.info("Output: %s", proc.stdout.decode())
+        self.log.warning("Stderr: %s", proc.stderr.decode())
+        self.log.info("Exit code %d", proc.returncode)
+        if proc.returncode != 0:
+            raise AirflowException(f"Process exit with non-zero exit code. Exit code: {proc.returncode}")
+        job_id = proc.stdout.decode().strip()
+
+        self.log.info("Created job ID: %s", job_id)
+        if on_new_job_id_callback:
+            on_new_job_id_callback(job_id)
+
+        jobs_controller = _DataflowJobsController(
+            dataflow=self.get_conn(),
+            project_number=project_id,
+            job_id=job_id,
+            location=location,
+            poll_sleep=self.poll_sleep,
+            num_retries=self.num_retries,
+            drain_pipeline=self.drain_pipeline,
+        )
+        jobs_controller.wait_for_done()
+
+        return jobs_controller.get_jobs(refresh=True)[0]
+
+    @GoogleBaseHook.fallback_to_default_project_id
+    def get_job(
+        self,
+        job_id: str,
+        project_id: str,
+        location: str = DEFAULT_DATAFLOW_LOCATION,
+    ) -> dict:
+        """
+        Gets the job with the specified Job ID.
+
+        :param job_id: Job ID to get.
+        :type job_id: str
+        :param project_id: Optional, the Google Cloud project ID in which to start a job.
+            If set to None or missing, the default project_id from the Google Cloud connection is used.
+        :type project_id:
+        :param location: The location of the Dataflow job (for example europe-west1). See:
+            https://cloud.google.com/dataflow/docs/concepts/regional-endpoints
+        :return: the Job
+        :rtype: dict
+        """
+        jobs_controller = _DataflowJobsController(
+            dataflow=self.get_conn(),
+            project_number=project_id,
+            location=location,
+        )
+        return jobs_controller.fetch_job_by_id(job_id)
+
+    @GoogleBaseHook.fallback_to_default_project_id
+    def fetch_job_metrics_by_id(
+        self,
+        job_id: str,
+        project_id: str,
+        location: str = DEFAULT_DATAFLOW_LOCATION,
+    ) -> dict:
+        """
+        Gets the job metrics with the specified Job ID.
+
+        :param job_id: Job ID to get.
+        :type job_id: str
+        :param project_id: Optional, the Google Cloud project ID in which to start a job.
+            If set to None or missing, the default project_id from the Google Cloud connection is used.
+        :type project_id:
+        :param location: The location of the Dataflow job (for example europe-west1). See:
+            https://cloud.google.com/dataflow/docs/concepts/regional-endpoints
+        :return: the JobMetrics. See:
+            https://cloud.google.com/dataflow/docs/reference/rest/v1b3/JobMetrics
+        :rtype: dict
+        """
+        jobs_controller = _DataflowJobsController(
+            dataflow=self.get_conn(),
+            project_number=project_id,
+            location=location,
+        )
+        return jobs_controller.fetch_job_metrics_by_id(job_id)
