@@ -15,9 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains Google Cloud Bigtable operators.
-"""
+"""This module contains Google Cloud Bigtable operators."""
 import enum
 from typing import Dict, Iterable, List, Optional, Sequence, Union
 
@@ -32,16 +30,14 @@ from airflow.utils.decorators import apply_defaults
 
 
 class BigtableValidationMixin:
-    """
-    Common class for Cloud Bigtable operators for validating required fields.
-    """
+    """Common class for Cloud Bigtable operators for validating required fields."""
 
     REQUIRED_ATTRIBUTES = []  # type: Iterable[str]
 
     def _validate_inputs(self):
         for attr_name in self.REQUIRED_ATTRIBUTES:
             if not getattr(self, attr_name):
-                raise AirflowException('Empty parameter: {}'.format(attr_name))
+                raise AirflowException(f'Empty parameter: {attr_name}')
 
 
 class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
@@ -153,7 +149,7 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -163,7 +159,7 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
             # Based on Instance.__eq__ instance with the same ID and client is
             # considered as equal.
             self.log.info(
-                "The instance '%s' already exists in this project. " "Consider it as created",
+                "The instance '%s' already exists in this project. Consider it as created",
                 self.instance_id,
             )
             return
@@ -259,7 +255,7 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -335,7 +331,7 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -344,7 +340,7 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
             hook.delete_instance(project_id=self.project_id, instance_id=self.instance_id)
         except google.api_core.exceptions.NotFound:
             self.log.info(
-                "The instance '%s' does not exist in project '%s'. " "Consider it as deleted",
+                "The instance '%s' does not exist in project '%s'. Consider it as deleted",
                 self.instance_id,
                 self.project_id,
             )
@@ -423,7 +419,7 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def _compare_column_families(self, hook, instance):
+    def _compare_column_families(self, hook, instance) -> bool:
         table_column_families = hook.get_column_families_for_table(instance, self.table_id)
         if set(table_column_families.keys()) != set(self.column_families.keys()):
             self.log.error("Table '%s' has different set of Column Families", self.table_id)
@@ -444,7 +440,7 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
                 return False
         return True
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -466,7 +462,7 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
         except google.api_core.exceptions.AlreadyExists:
             if not self._compare_column_families(hook, instance):
                 raise AirflowException(
-                    "Table '{}' already exists with different Column Families.".format(self.table_id)
+                    f"Table '{self.table_id}' already exists with different Column Families."
                 )
             self.log.info("The table '%s' already exists. Consider it as created", self.table_id)
 
@@ -533,14 +529,14 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
         )
         instance = hook.get_instance(project_id=self.project_id, instance_id=self.instance_id)
         if not instance:
-            raise AirflowException("Dependency: instance '{}' does not exist.".format(self.instance_id))
+            raise AirflowException(f"Dependency: instance '{self.instance_id}' does not exist.")
 
         try:
             hook.delete_table(
@@ -619,14 +615,14 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
         )
         instance = hook.get_instance(project_id=self.project_id, instance_id=self.instance_id)
         if not instance:
-            raise AirflowException("Dependency: instance '{}' does not exist.".format(self.instance_id))
+            raise AirflowException(f"Dependency: instance '{self.instance_id}' does not exist.")
 
         try:
             hook.update_cluster(instance=instance, cluster_id=self.cluster_id, nodes=self.nodes)
